@@ -59,7 +59,7 @@
 using namespace KDevelop;
 
 K_PLUGIN_FACTORY(KDevPhpSupportFactory, registerPlugin<Php::LanguageSupport>();)
-K_EXPORT_PLUGIN(KDevPhpSupportFactory(KAboutData("kdevphpsupport","kdevphp", ki18n("Php Support"), "1.0.1", ki18n("Support for Php Language"), KAboutData::License_GPL)
+K_EXPORT_PLUGIN(KDevPhpSupportFactory(KAboutData("kdevphpsupport","kdevphp", ki18n("Php Support"), "1.0.2", ki18n("Support for Php Language"), KAboutData::License_GPL)
     .addAuthor(ki18n("Milian Wolff"), ki18n("Author"), "mail@milianw.de", "http://milianw.de")
     .addAuthor(ki18n("Niko Sams"), ki18n("Author"), "niko.sams@gmail.com", "http://nikosams.blogspot.com")
 ))
@@ -129,8 +129,10 @@ QReadWriteLock* LanguageSupport::internalFunctionsLock()
 
 KDevelop::ParseJob *LanguageSupport::createParseJob(const KUrl &url)
 {
-    if ( url.fileName().endsWith(".gz", Qt::CaseInsensitive) && !url.fileName().endsWith(".php.gz", Qt::CaseInsensitive) ) {
-        // only support *.php.gz files
+    if ( !url.fileName().endsWith(".php") && KMimeType::findByUrl(url)->name() == "application/x-gzip"
+          && !url.fileName().endsWith(".php.gz", Qt::CaseInsensitive) )
+    {
+        // only support *.php.gz files, not arbitrary gzip files (might lead to crashes...)
         return 0;
     }
     return new ParseJob(url);
